Baunsgaard commented on pull request #1213: URL: https://github.com/apache/systemds/pull/1213#issuecomment-808141699
Overall for two epoch Mnist with batch size 128 we go from 254 sec to 195 sec -- This is an automated message from the Apache Git Service. To respond to the message, please log on to GitHub and use the URL above to go to the specific comment. For queries about this service, please contact Infrastructure at: [email protected]
